@@ -2,8 +2,8 @@ from typing import List, Generator
 from pathlib import Path
 from collections import defaultdict
 
-from domain.mecab_exception import MecabDataReaderException
-from mecab_parser import MecabParser
+from .domain.mecab_exception import MecabDataReaderException
+from .mecab_parser import MecabParser
 
 
 class CategoryData:
@@ -16,6 +16,7 @@ class CategoryData:
 
 class MecabDataReader:
     FIRST_WORD = 0
+    MECAB_DATA = "mecab_data"
 
     FORMAT_SUFFIX = ".txt"
     HEADER = "#"
@@ -106,7 +107,6 @@ class MecabDataWriter(MecabDataReader):
     ORIGIN_WORD = 0
 
     ITEM_BOUNDARY = ","
-    MECAB_DATA = "mecab_data"
     CATEGORY_SPLITER = "_"
 
 
